@@ -78,7 +78,7 @@ static char **opt_add_tags;
 static char **opt_remove_tags;
 static int opt_jobs;
 static char *opt_mirror_screenshots_url;
-static char *opt_install_deps_from;
+static char **opt_install_deps_from;
 static gboolean opt_install_deps_only;
 static gboolean opt_user;
 static char *opt_installation;
@@ -129,7 +129,7 @@ static GOptionEntry entries[] = {
   { "from-git-branch", 0, 0, G_OPTION_ARG_STRING, &opt_from_git_branch, "Branch to use in --from-git", "BRANCH"},
   { "mirror-screenshots-url", 0, 0, G_OPTION_ARG_STRING, &opt_mirror_screenshots_url, "Download and rewrite screenshots to match this url", "URL"},
   { "install", 0, 0, G_OPTION_ARG_NONE, &opt_install, "Install if build succeeds", NULL},
-  { "install-deps-from", 0, 0, G_OPTION_ARG_STRING, &opt_install_deps_from, "Install build dependencies from this remote", "REMOTE"},
+  { "install-deps-from", 0, 0, G_OPTION_ARG_STRING_ARRAY, &opt_install_deps_from, "Install build dependencies from this remote", "REMOTE"},
   { "install-deps-only", 0, 0, G_OPTION_ARG_NONE, &opt_install_deps_only, "Stop after installing dependencies"},
   { "user", 0, 0, G_OPTION_ARG_NONE, &opt_user, "Install dependencies in user installations", NULL },
   { "system", 0, G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &opt_user, "Install dependencies in system-wide installations (default)", NULL },
@@ -256,46 +256,6 @@ do_export (BuilderContext *build_context,
   return TRUE;
 }
 
-static gboolean
-flatpak_version_check (int major,
-                       int minor,
-                       int micro)
-{
-  static int flatpak_major = 0;
-  static int flatpak_minor = 0;
-  static int flatpak_micro = 0;
-
-  if (flatpak_major == 0 &&
-      flatpak_minor == 0 &&
-      flatpak_micro == 0)
-    {
-      const char * argv[] = { "flatpak", "--version", NULL };
-      g_autoptr(GSubprocess) subp = NULL;
-      g_autofree char *out = NULL;
- 
-      subp = g_subprocess_newv (argv, G_SUBPROCESS_FLAGS_STDOUT_PIPE, NULL);
-      g_subprocess_communicate_utf8 (subp, NULL, NULL, &out, NULL, NULL);
-
-      if (sscanf (out, "Flatpak %d.%d.%d", &flatpak_major, &flatpak_minor, &flatpak_micro) != 3)
-        g_warning ("Failed to get flatpak version");
-
-      g_debug ("Using Flatpak version %d.%d.%d", flatpak_major, flatpak_minor, flatpak_micro);
-    }
-
-  if (flatpak_major > major)
-    return TRUE;
-  if (flatpak_major < major)
-    return FALSE;
-  if (flatpak_minor > minor)
-    return TRUE;
-  if (flatpak_minor < minor)
-    return FALSE;
-  if (flatpak_micro >= micro)
-    return TRUE;
-
-  return FALSE;
-}
-
 static gboolean
 do_install (BuilderContext *build_context,
             const gchar    *repodir,
